@@ -105,6 +105,7 @@ var flagRules = []linter.FlagRule{
 			"max-partition-memory-bytes",
 			"message-send-max-retries",
 			"private-link-access-point",
+			"record-failure-strategy",
 			"remote-api-key",
 			"remote-api-secret",
 			"remote-bootstrap-server",
@@ -205,6 +206,7 @@ var vocabWords = []string{
 	"base64",
 	"bedrock",
 	"byok",
+	"byos",
 	"cel",
 	"cfu",
 	"cidr",
@@ -282,6 +284,7 @@ var vocabWords = []string{
 	"recv",
 	"restapi",
 	"ruleset",
+	"s3",
 	"sagemaker",
 	"sasl",
 	"scala",
