@@ -9,30 +9,18 @@ import (
 	"github.com/confluentinc/cli/v4/pkg/config"
 )
 
-const (
-	singleZone       = "single-zone"
-	multiZone        = "multi-zone"
-	lowAvailability  = "SINGLE_ZONE"
-	highAvailability = "MULTI_ZONE"
-	low              = "LOW"
-	high             = "HIGH"
-)
-
-var availabilitiesToHuman = map[string]string{
-	lowAvailability:  singleZone,
-	highAvailability: multiZone,
-	low:              singleZone,
-	high:             multiZone,
-}
-
 var availabilitiesToModel = map[string]string{
-	singleZone: lowAvailability,
-	multiZone:  highAvailability,
+	"single-zone": "SINGLE_ZONE",
+	"multi-zone":  "MULTI_ZONE",
+	"low":         "LOW",
+	"high":        "HIGH",
 }
 
 var availabilitiesToFreightModel = map[string]string{
-	singleZone: low,
-	multiZone:  high,
+	"single-zone": "LOW",  // TODO: This mapping is deprecated and will be removed in v5
+	"multi-zone":  "HIGH", // TODO: This mapping is deprecated and will be removed in v5
+	"low":         "LOW",
+	"high":        "HIGH",
 }
 
 type clusterCommand struct {
