@@ -17,19 +17,22 @@ import (
 )
 
 const (
-	awsEgressPrivateLink       = "AwsEgressPrivateLink"
-	awsPeering                 = "AwsPeering"
-	azureEgressPrivateLink     = "AzureEgressPrivateLink"
-	azurePeering               = "AzurePeering"
-	awsPrivateNetworkInterface = "AwsPrivateNetworkInterface"
+	awsEgressPrivateLink           = "AwsEgressPrivateLink"
+	awsPeering                     = "AwsPeering"
+	azureEgressPrivateLink         = "AzureEgressPrivateLink"
+	azurePeering                   = "AzurePeering"
+	awsPrivateNetworkInterface     = "AwsPrivateNetworkInterface"
+	gcpPeering                     = "GcpPeering"
+	gcpEgressPrivateServiceConnect = "GcpEgressPrivateServiceConnect"
 )
 
 var (
 	createGatewayTypes = []string{"egress-privatelink", "private-network-interface"}
-	listGatewayTypes   = []string{"aws-egress-privatelink", "azure-egress-privatelink"} // TODO: check if we accept private-network-interface here
+	listGatewayTypes   = []string{"aws-egress-privatelink", "azure-egress-privatelink", "gcp-egress-private-service-connect"} // TODO: check if we accept private-network-interface here
 	gatewayTypeMap     = map[string]string{
-		"aws-egress-privatelink":   awsEgressPrivateLink,
-		"azure-egress-privatelink": azureEgressPrivateLink,
+		"aws-egress-privatelink":             awsEgressPrivateLink,
+		"azure-egress-privatelink":           azureEgressPrivateLink,
+		"gcp-egress-private-service-connect": gcpEgressPrivateServiceConnect,
 	}
 )
 
@@ -41,6 +44,8 @@ type gatewayOut struct {
 	Type              string   `human:"Type,omitempty" serialized:"type,omitempty"`
 	AwsPrincipalArn   string   `human:"AWS Principal ARN,omitempty" serialized:"aws_principal_arn,omitempty"`
 	AzureSubscription string   `human:"Azure Subscription,omitempty" serialized:"azure_subscription,omitempty"`
+	GcpIamPrincipal   string   `human:"GCP IAM Principal,omitempty" serialized:"gcp_iam_principal,omitempty"`
+	GcpProject        string   `human:"GCP Project,omitempty" serialized:"gcp_project,omitempty"`
 	Phase             string   `human:"Phase" serialized:"phase"`
 	Zones             []string `human:"Zones,omitempty" serialized:"zones,omitempty"`
 	Account           string   `human:"Account,omitempty" serialized:"account,omitempty"`
@@ -133,6 +138,14 @@ func getGatewayCloud(gateway networkinggatewayv1.NetworkingV1Gateway) string {
 		return pcloud.Azure
 	}
 
+	if cloud.NetworkingV1GcpEgressPrivateServiceConnectGatewayStatus != nil {
+		return pcloud.Gcp
+	}
+
+	if cloud.NetworkingV1GcpPeeringGatewayStatus != nil {
+		return pcloud.Gcp
+	}
+
 	return ""
 }
 
@@ -159,6 +172,14 @@ func getGatewayType(gateway networkinggatewayv1.NetworkingV1Gateway) (string, er
 		return azurePeering, nil
 	}
 
+	if config.NetworkingV1GcpPeeringGatewaySpec != nil {
+		return gcpPeering, nil
+	}
+
+	if config.NetworkingV1GcpEgressPrivateServiceConnectGatewaySpec != nil {
+		return gcpEgressPrivateServiceConnect, nil
+	}
+
 	return "", fmt.Errorf(errors.CorruptedNetworkResponseErrorMsg, "config")
 }
 
@@ -200,6 +221,12 @@ func printGatewayTable(cmd *cobra.Command, gateway networkinggatewayv1.Networkin
 		out.Region = gateway.Spec.Config.NetworkingV1AwsPrivateNetworkInterfaceGatewaySpec.GetRegion()
 		out.Zones = gateway.Spec.Config.NetworkingV1AwsPrivateNetworkInterfaceGatewaySpec.GetZones()
 	}
+	if gatewayType == gcpEgressPrivateServiceConnect {
+		out.Region = gateway.Spec.Config.NetworkingV1GcpEgressPrivateServiceConnectGatewaySpec.GetRegion()
+	}
+	if gatewayType == gcpPeering {
+		out.Region = gateway.Spec.Config.NetworkingV1GcpPeeringGatewaySpec.GetRegion()
+	}
 
 	switch getGatewayCloud(gateway) {
 	case pcloud.Aws:
@@ -210,6 +237,9 @@ func printGatewayTable(cmd *cobra.Command, gateway networkinggatewayv1.Networkin
 		}
 	case pcloud.Azure:
 		out.AzureSubscription = gateway.Status.CloudGateway.NetworkingV1AzureEgressPrivateLinkGatewayStatus.GetSubscription()
+	case pcloud.Gcp:
+		out.GcpProject = gateway.Status.CloudGateway.NetworkingV1GcpEgressPrivateServiceConnectGatewayStatus.GetProject()
+		out.GcpIamPrincipal = gateway.Status.CloudGateway.NetworkingV1GcpPeeringGatewayStatus.GetIamPrincipal()
 	}
 
 	table := output.NewTable(cmd)
