@@ -12,18 +12,15 @@ import (
 )
 
 func TestNewStateDev(t *testing.T) {
-	state, err := newState("https://devel.cpdev.cloud/", false)
+	state, err := NewState("https://devel.cpdev.cloud/", false)
 	require.NoError(t, err)
-	// randomly generated
 	require.True(t, len(state.CodeVerifier) > 10)
 	require.True(t, len(state.CodeChallenge) > 10)
 	require.True(t, len(state.SSOProviderState) > 10)
-	// make sure we didn't so something dumb generating the hashes
 	require.True(t,
 		(state.CodeVerifier != state.CodeChallenge) &&
 			(state.CodeVerifier != state.SSOProviderState) &&
 			(state.CodeChallenge != state.SSOProviderState))
-	// dev configs
 	require.Equal(t, "https://login.confluent-dev.io/oauth", state.SSOProviderHost)
 	require.Equal(t, "sPhOuMMVRSFFR7HfB606KLxf1RAU4SXg", state.SSOProviderClientID)
 	require.Equal(t, "http://127.0.0.1:26635/cli_callback", state.SSOProviderCallbackUrl)
@@ -31,8 +28,7 @@ func TestNewStateDev(t *testing.T) {
 	require.Empty(t, state.SSOProviderAuthenticationCode)
 	require.Empty(t, state.SSOProviderIDToken)
 
-	// check stag configs
-	stateStag, err := newState("https://stag.cpdev.cloud/", false)
+	stateStag, err := NewState("https://stag.cpdev.cloud/", false)
 	require.NoError(t, err)
 	require.Equal(t, "https://login-stag.confluent-dev.io/oauth", stateStag.SSOProviderHost)
 	require.Equal(t, "8RxQmZEYtEDah4MTIIzl4hGGeFwdJS6w", stateStag.SSOProviderClientID)
@@ -43,19 +39,16 @@ func TestNewStateDev(t *testing.T) {
 }
 
 func TestNewStateDevNoBrowser(t *testing.T) {
-	state, err := newState("https://devel.cpdev.cloud", true)
+	state, err := NewState("https://devel.cpdev.cloud", true)
 	require.NoError(t, err)
-	// randomly generated
 	require.True(t, len(state.CodeVerifier) > 10)
 	require.True(t, len(state.CodeChallenge) > 10)
 	require.True(t, len(state.SSOProviderState) > 10)
-	// make sure we didn't so something dumb generating the hashes
 	require.True(t,
 		(state.CodeVerifier != state.CodeChallenge) &&
 			(state.CodeVerifier != state.SSOProviderState) &&
 			(state.CodeChallenge != state.SSOProviderState))
 
-	// dev configs
 	require.Equal(t, "https://login.confluent-dev.io/oauth", state.SSOProviderHost)
 	require.Equal(t, "sPhOuMMVRSFFR7HfB606KLxf1RAU4SXg", state.SSOProviderClientID)
 	require.Equal(t, "https://devel.cpdev.cloud/cli_callback", state.SSOProviderCallbackUrl)
@@ -63,8 +56,7 @@ func TestNewStateDevNoBrowser(t *testing.T) {
 	require.Empty(t, state.SSOProviderAuthenticationCode)
 	require.Empty(t, state.SSOProviderIDToken)
 
-	// check stag configs
-	stateStag, err := newState("https://stag.cpdev.cloud", true)
+	stateStag, err := NewState("https://stag.cpdev.cloud", true)
 	require.NoError(t, err)
 	require.Equal(t, "https://login-stag.confluent-dev.io/oauth", stateStag.SSOProviderHost)
 	require.Equal(t, "8RxQmZEYtEDah4MTIIzl4hGGeFwdJS6w", stateStag.SSOProviderClientID)
@@ -75,13 +67,11 @@ func TestNewStateDevNoBrowser(t *testing.T) {
 }
 
 func TestNewStateProd(t *testing.T) {
-	state, err := newState("https://confluent.cloud", false)
+	state, err := NewState("https://confluent.cloud", false)
 	require.NoError(t, err)
-	// randomly generated
 	require.True(t, len(state.CodeVerifier) > 10)
 	require.True(t, len(state.CodeChallenge) > 10)
 	require.True(t, len(state.SSOProviderState) > 10)
-	// make sure we didn't so something dumb generating the hashes
 	require.True(t,
 		(state.CodeVerifier != state.CodeChallenge) &&
 			(state.CodeVerifier != state.SSOProviderState) &&
@@ -96,15 +86,13 @@ func TestNewStateProd(t *testing.T) {
 
 func TestNewStateProdNoBrowser(t *testing.T) {
 	for _, authURL := range []string{"", "https://confluent.cloud"} {
-		state, err := newState(authURL, true)
+		state, err := NewState(authURL, true)
 		require.NoError(t, err)
 
-		// randomly generated
 		require.True(t, len(state.CodeVerifier) > 10)
 		require.True(t, len(state.CodeChallenge) > 10)
 		require.True(t, len(state.SSOProviderState) > 10)
 
-		// make sure we didn't so something dumb generating the hashes
 		require.True(t,
 			(state.CodeVerifier != state.CodeChallenge) &&
 				(state.CodeVerifier != state.SSOProviderState) &&
@@ -120,16 +108,15 @@ func TestNewStateProdNoBrowser(t *testing.T) {
 }
 
 func TestNewStateInvalidUrl(t *testing.T) {
-	state, err := newState("Invalid url", true)
+	state, err := NewState("Invalid url", true)
 	require.NoError(t, err)
 	require.NotNil(t, state)
 }
 
 func TestGetAuthorizationUrl(t *testing.T) {
-	state, err := newState("https://devel.cpdev.cloud", false)
+	state, err := NewState("https://devel.cpdev.cloud", false)
 	require.NoError(t, err)
 
-	// test get auth code url
 	authCodeUrlDevel := state.getAuthorizationCodeUrl("foo", false)
 	expectedUri := "/authorize?" +
 		"response_type=code" +
@@ -145,9 +132,7 @@ func TestGetAuthorizationUrl(t *testing.T) {
 	require.Equal(t, authCodeUrlDevel, expectedUrl)
 
 	server := httptest.NewServer(http.HandlerFunc(func(rw http.ResponseWriter, req *http.Request) {
-		// Test request parameters
 		require.Equal(t, req.URL.String(), expectedUri)
-		// Send response to be tested
 		_, e := rw.Write([]byte(`OK`))
 		require.NoError(t, e)
 	}))
@@ -158,7 +143,7 @@ func TestGetAuthorizationUrl(t *testing.T) {
 func TestGetOAuthToken(t *testing.T) {
 	mockRefreshToken := "foo"
 
-	state, err := newState("https://devel.cpdev.cloud", false)
+	state, err := NewState("https://devel.cpdev.cloud", false)
 	require.NoError(t, err)
 
 	expectedUri := "/token"
@@ -170,21 +155,18 @@ func TestGetOAuthToken(t *testing.T) {
 
 	mockIDToken := "foobar"
 	server := httptest.NewServer(http.HandlerFunc(func(rw http.ResponseWriter, req *http.Request) {
-		// Test request parameters
 		require.Equal(t, req.URL.String(), expectedUri)
 		body, err := io.ReadAll(req.Body)
 		require.NoError(t, err)
 		require.True(t, len(body) > 0)
 		require.Equal(t, expectedPayload, string(body))
 
-		// mock response
 		_, err = rw.Write([]byte(fmt.Sprintf(`{"id_token": "%s", "refresh_token": "%s"}`, mockIDToken, mockRefreshToken)))
 		require.NoError(t, err)
 	}))
 	defer server.Close()
 	serverPort := strings.Split(server.URL, ":")[2]
 
-	// mock auth0 endpoint with local test server
 	state.SSOProviderHost = "http://127.0.0.1:" + serverPort
 
 	err = state.getOAuthToken()
@@ -197,7 +179,7 @@ func TestRefreshOAuthToken(t *testing.T) {
 	mockRefreshToken1 := "foo"
 	mockRefreshToken2 := "bar"
 
-	state, err := newState("https://devel.cpdev.cloud", false)
+	state, err := NewState("https://devel.cpdev.cloud", false)
 	require.NoError(t, err)
 	state.SSOProviderRefreshToken = mockRefreshToken1
 
@@ -209,21 +191,17 @@ func TestRefreshOAuthToken(t *testing.T) {
 
 	mockIDToken := "foobar"
 	server := httptest.NewServer(http.HandlerFunc(func(rw http.ResponseWriter, req *http.Request) {
-		// Test request parameters
 		require.Equal(t, req.URL.String(), expectedUri)
 		body, err := io.ReadAll(req.Body)
 		require.NoError(t, err)
 		require.True(t, len(body) > 0)
 		require.Equal(t, expectedPayload, string(body))
 
-		// mock response
 		_, err = rw.Write([]byte(fmt.Sprintf(`{"id_token": "%s", "refresh_token": "%s"}`, mockIDToken, mockRefreshToken2)))
 		require.NoError(t, err)
 	}))
 	defer server.Close()
 	serverPort := strings.Split(server.URL, ":")[2]
-
-	// mock auth0 endpoint with local test server
 	state.SSOProviderHost = "http://127.0.0.1:" + serverPort
 
 	err = state.refreshOAuthToken()
