@@ -32,6 +32,7 @@ import (
 	srcmv3 "github.com/confluentinc/ccloud-sdk-go-v2/srcm/v3"
 	srcmv3Access "github.com/confluentinc/ccloud-sdk-go-v2/srcmv3access/v1"
 	ssov2 "github.com/confluentinc/ccloud-sdk-go-v2/sso/v2"
+	tableflowv1 "github.com/confluentinc/ccloud-sdk-go-v2/tableflow/v1"
 
 	"github.com/confluentinc/cli/v4/pkg/config"
 	testserver "github.com/confluentinc/cli/v4/test/test-server"
@@ -72,6 +73,7 @@ type Client struct {
 	SrcmClient                   *srcmv3.APIClient
 	SrcmV3AcessClient            *srcmv3Access.APIClient
 	SsoClient                    *ssov2.APIClient
+	TableflowClient              *tableflowv1.APIClient
 }
 
 func NewClient(cfg *config.Config, unsafeTrace bool) *Client {
@@ -118,5 +120,6 @@ func NewClient(cfg *config.Config, unsafeTrace bool) *Client {
 		SrcmClient:                   newSrcmClient(httpClient, url, userAgent, unsafeTrace),
 		SrcmV3AcessClient:            newSrcmV3AccessClient(httpClient, url, userAgent, unsafeTrace),
 		SsoClient:                    newSsoClient(httpClient, url, userAgent, unsafeTrace),
+		TableflowClient:              newTableflowClient(httpClient, url, userAgent, unsafeTrace),
 	}
 }
