@@ -25,6 +25,7 @@ type Context struct {
 	KafkaClusterContext *KafkaClusterContext           `json:"kafka_cluster_context"`
 	LastOrgId           string                         `json:"last_org_id,omitempty"`
 	FeatureFlags        *FeatureFlags                  `json:"feature_flags,omitempty"`
+	IsMFA               bool                           `json:"is_mfa,omitempty"`
 
 	// Deprecated
 	NetrcMachineName       string                            `json:"netrc_machine_name,omitempty"`
@@ -38,7 +39,7 @@ type Context struct {
 
 var noEnvError = "no environment found"
 
-func newContext(name string, platform *Platform, credential *Credential, kafkaClusters map[string]*KafkaClusterConfig, kafka string, state *ContextState, config *Config, organizationId, environmentId string) (*Context, error) {
+func newContext(name string, platform *Platform, credential *Credential, kafkaClusters map[string]*KafkaClusterConfig, kafka string, state *ContextState, config *Config, organizationId, environmentId string, isMFA bool) (*Context, error) {
 	ctx := &Context{
 		Name:               name,
 		MachineName:        name,
@@ -51,6 +52,7 @@ func newContext(name string, platform *Platform, credential *Credential, kafkaCl
 		State:              state,
 		Config:             config,
 		LastOrgId:          organizationId,
+		IsMFA:              isMFA,
 	}
 	ctx.KafkaClusterContext = NewKafkaClusterContext(ctx, kafka, kafkaClusters)
 	if err := ctx.validate(); err != nil {
