@@ -13,7 +13,7 @@ func TestSetAutoCompletionSnapshot(t *testing.T) {
 	buffer := prompt.NewBuffer()
 	buffer.InsertText(input, false, true)
 
-	completer := NewCompleterBuilder(mockGetSmartCompletion).
+	completer := NewCompleterBuilder(mockCompletionsEnabled).
 		AddCompleter(SetCompleter).
 		BuildCompleter()
 
