@@ -2,6 +2,6 @@ package kafka
 
 var (
 	Clouds         = []string{"aws", "azure", "gcp"}
-	Availabilities = []string{"single-zone", "multi-zone"}
+	Availabilities = []string{"single-zone", "multi-zone", "low", "high"}
 	Types          = []string{"basic", "standard", "enterprise", "freight", "dedicated"}
 )
