@@ -8,7 +8,7 @@ import (
 )
 
 // FilterUpdates takes the HTML content of the binaries page and returns the versions that are valid minor and major updates.
-func FilterUpdates(binaries string, current *version.Version, major bool) (version.Collection, version.Collection) {
+func FilterUpdates(binaries string, current *version.Version) (version.Collection, version.Collection) {
 	matches := regexp.MustCompile(`<a href="/confluent-cli/binaries/([0-9]+\.[0-9]+\.[0-9]+)/">`).FindAllStringSubmatch(binaries, -1)
 
 	versions := make(version.Collection, len(matches))
@@ -24,12 +24,6 @@ func FilterUpdates(binaries string, current *version.Version, major bool) (versi
 		versions = versions[idx+1:]
 	}
 
-	if !major {
-		// Remove major versions
-		if idx := sort.Search(len(versions), func(i int) bool { return current.Segments()[0] < versions[i].Segments()[0] }); idx < len(versions) {
-			return versions[:idx], versions
-		}
-	}
-
-	return versions, versions
+	idx := sort.Search(len(versions), func(i int) bool { return versions[i].Segments()[0] > current.Segments()[0] })
+	return versions[:idx], versions[idx:]
 }
