@@ -466,6 +466,110 @@ func handleCustomConnectorPluginsId(t *testing.T) http.HandlerFunc {
 	}
 }
 
+// Handler for: "/connect/v1/custom-connector-plugins/{plugin_id}/versions"
+func handleCustomConnectorPluginsVersions(t *testing.T) http.HandlerFunc {
+	return func(w http.ResponseWriter, r *http.Request) {
+		switch r.Method {
+		case http.MethodPost:
+			vars := mux.Vars(r)
+			id := vars["plugin_id"]
+			var version connectcustompluginv1.ConnectV1CustomConnectorPluginVersion
+			if id == "ccp-123456" {
+				version = connectcustompluginv1.ConnectV1CustomConnectorPluginVersion{
+					Id:           connectcustompluginv1.PtrString("ver-123456"),
+					Version:      connectcustompluginv1.PtrString("0.0.0"),
+					IsBeta:       connectcustompluginv1.PtrString("false"),
+					ReleaseNotes: connectcustompluginv1.PtrString("test release notes"),
+				}
+			} else if id == "ccp-789012" {
+				sensitiveProperties := []string{"aws.key", "aws.secret"}
+				version = connectcustompluginv1.ConnectV1CustomConnectorPluginVersion{
+					Id:                        connectcustompluginv1.PtrString("ver-123456"),
+					Version:                   connectcustompluginv1.PtrString("0.0.0"),
+					IsBeta:                    connectcustompluginv1.PtrString("false"),
+					ReleaseNotes:              connectcustompluginv1.PtrString("test release notes"),
+					SensitiveConfigProperties: &sensitiveProperties,
+				}
+			} else {
+				version = connectcustompluginv1.ConnectV1CustomConnectorPluginVersion{
+					Id:           connectcustompluginv1.PtrString("ver-123456"),
+					Version:      connectcustompluginv1.PtrString("0.0.0"),
+					IsBeta:       connectcustompluginv1.PtrString("false"),
+					ReleaseNotes: connectcustompluginv1.PtrString("test release notes"),
+				}
+			}
+			err := json.NewEncoder(w).Encode(version)
+			require.NoError(t, err)
+		case http.MethodGet:
+			version1 := connectcustompluginv1.ConnectV1CustomConnectorPluginVersion{
+				Id:      connectcustompluginv1.PtrString("ver-123456"),
+				Version: connectcustompluginv1.PtrString("0.0.0"),
+				IsBeta:  connectcustompluginv1.PtrString("false"),
+			}
+			version2 := connectcustompluginv1.ConnectV1CustomConnectorPluginVersion{
+				Id:      connectcustompluginv1.PtrString("ver-123456"),
+				Version: connectcustompluginv1.PtrString("0.0.1"),
+				IsBeta:  connectcustompluginv1.PtrString("false"),
+			}
+			version3 := connectcustompluginv1.ConnectV1CustomConnectorPluginVersion{
+				Id:      connectcustompluginv1.PtrString("ver-123456"),
+				Version: connectcustompluginv1.PtrString("0.0.2"),
+				IsBeta:  connectcustompluginv1.PtrString("true"),
+			}
+
+			err := json.NewEncoder(w).Encode(connectcustompluginv1.ConnectV1CustomConnectorPluginVersionList{Data: []connectcustompluginv1.ConnectV1CustomConnectorPluginVersion{version1, version2, version3}})
+			require.NoError(t, err)
+		}
+	}
+}
+
+// Handler for: "/connect/v1/custom-connector-plugins/{plugin_id}/versions/{version_id}"
+func handleCustomConnectorPluginsVersionsId(t *testing.T) http.HandlerFunc {
+	return func(w http.ResponseWriter, r *http.Request) {
+		switch r.Method {
+		case http.MethodGet:
+			vars := mux.Vars(r)
+			verId := vars["version_id"]
+			var version connectcustompluginv1.ConnectV1CustomConnectorPluginVersion
+			if verId == "ver-123456" {
+				version = connectcustompluginv1.ConnectV1CustomConnectorPluginVersion{
+					Id:           connectcustompluginv1.PtrString("ver-123456"),
+					Version:      connectcustompluginv1.PtrString("0.0.0"),
+					IsBeta:       connectcustompluginv1.PtrString("false"),
+					ReleaseNotes: connectcustompluginv1.PtrString("test release notes"),
+				}
+			} else if verId == "ver-789012" {
+				sensitiveProperties := []string{"aws.key", "aws.secret"}
+				version = connectcustompluginv1.ConnectV1CustomConnectorPluginVersion{
+					Id:                        connectcustompluginv1.PtrString("ver-789012"),
+					Version:                   connectcustompluginv1.PtrString("0.0.0"),
+					IsBeta:                    connectcustompluginv1.PtrString("false"),
+					ReleaseNotes:              connectcustompluginv1.PtrString("test release notes"),
+					SensitiveConfigProperties: &sensitiveProperties,
+				}
+			} else {
+				version = connectcustompluginv1.ConnectV1CustomConnectorPluginVersion{
+					Id:           connectcustompluginv1.PtrString("ver-123456"),
+					Version:      connectcustompluginv1.PtrString("0.0.0"),
+					IsBeta:       connectcustompluginv1.PtrString("false"),
+					ReleaseNotes: connectcustompluginv1.PtrString("test release notes"),
+				}
+			}
+			err := json.NewEncoder(w).Encode(version)
+			require.NoError(t, err)
+		case http.MethodPatch:
+			version1 := connectcustompluginv1.ConnectV1CustomConnectorPluginVersion{
+				Id:           connectcustompluginv1.PtrString("ver-123456"),
+				Version:      connectcustompluginv1.PtrString("0.0.0"),
+				IsBeta:       connectcustompluginv1.PtrString("false"),
+				ReleaseNotes: connectcustompluginv1.PtrString("test release notes"),
+			}
+			err := json.NewEncoder(w).Encode(version1)
+			require.NoError(t, err)
+		}
+	}
+}
+
 // Handler for: "/connect/v1/presigned-upload-url"
 func handleCustomPluginUploadUrl(t *testing.T) http.HandlerFunc {
 	return func(w http.ResponseWriter, r *http.Request) {
