@@ -590,14 +590,18 @@ func handleIamIpFilters(t *testing.T) http.HandlerFunc {
 			var req iamipfilteringv2.IamV2IpFilter
 			err := json.NewDecoder(r.Body).Decode(&req)
 			require.NoError(t, err)
-
+			opGroups := req.OperationGroups
+			if *req.ResourceGroup == "management" {
+				opGroups = &[]string{"MANAGEMENT"}
+				req.ResourceGroup = iamipfilteringv2.PtrString("multiple")
+			}
 			ipFilter := &iamipfilteringv2.IamV2IpFilter{
 				Id:              iamipfilteringv2.PtrString(ipFilterId),
 				FilterName:      req.FilterName,
 				ResourceGroup:   req.ResourceGroup,
 				IpGroups:        req.IpGroups,
-				ResourceScope:   req.ResourceScope,
-				OperationGroups: req.OperationGroups,
+				ResourceScope:   iamipfilteringv2.PtrString("crn://confluent.cloud/organization=org123"),
+				OperationGroups: opGroups,
 			}
 			err = json.NewEncoder(w).Encode(ipFilter)
 			require.NoError(t, err)
@@ -624,7 +628,21 @@ func handleIamIpFilter(t *testing.T) http.HandlerFunc {
 			err = json.NewEncoder(w).Encode(res)
 			require.NoError(t, err)
 		case http.MethodGet:
-			ipFilter := buildIamIpFilter(ipFilterId, "demo-ip-filter", "multiple", []string{"ipg-12345", "ipg-abcde"}, "", []string{"MANAGEMENT"})
+			var ipFilter iamipfilteringv2.IamV2IpFilter
+			segments := strings.Split(r.URL.String(), "/")
+			var filterId string
+			if len(segments) > 0 {
+				filterId = segments[len(segments)-1] // "ipf-34dq3"
+			}
+			var operationGroups []string
+			if filterId == "ipf-34dq4" {
+				operationGroups = []string{"MANAGEMENT", "SCHEMA"}
+			} else if filterId == "ipf-34dq6" {
+				operationGroups = []string{"MANAGEMENT", "SCHEMA", "FLINK"}
+			} else {
+				operationGroups = []string{"MANAGEMENT"}
+			}
+			ipFilter = buildIamIpFilter(ipFilterId, "demo-ip-filter", "multiple", []string{"ipg-12345", "ipg-abcde"}, "crn://confluent.cloud/organization=org123", operationGroups)
 			err := json.NewEncoder(w).Encode(ipFilter)
 			require.NoError(t, err)
 		case http.MethodDelete:
@@ -642,10 +660,10 @@ func handleIamIpGroups(t *testing.T) http.HandlerFunc {
 			err := json.NewEncoder(w).Encode(iamipfilteringv2.IamV2IpGroupList{Data: []iamipfilteringv2.IamV2IpGroup{ipGroup}})
 			require.NoError(t, err)
 		case http.MethodPost:
-			var req iamv2.IamV2IpGroup
+			var req iamipfilteringv2.IamV2IpGroup
 			err := json.NewDecoder(r.Body).Decode(&req)
 			require.NoError(t, err)
-			ipGroup := &iamv2.IamV2IpGroup{
+			ipGroup := &iamipfilteringv2.IamV2IpGroup{
 				Id:         iamv2.PtrString(ipGroupId),
 				GroupName:  req.GroupName,
 				CidrBlocks: req.CidrBlocks,
@@ -661,10 +679,10 @@ func handleIamIpGroup(t *testing.T) http.HandlerFunc {
 	return func(w http.ResponseWriter, r *http.Request) {
 		switch r.Method {
 		case http.MethodPatch:
-			var req iamv2.IamV2IpGroup
+			var req iamipfilteringv2.IamV2IpGroup
 			err := json.NewDecoder(r.Body).Decode(&req)
 			require.NoError(t, err)
-			res := &iamv2.IamV2IpGroup{
+			res := &iamipfilteringv2.IamV2IpGroup{
 				Id:         req.Id,
 				GroupName:  req.GroupName,
 				CidrBlocks: req.CidrBlocks,
